/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.raster;

import de.intevation.gnv.raster.Vectorizer.RingsHandler;

/**
 * Abstract base class for producing multi polygons and
 * multi line strings. This base class stores a bounding box
 * of world coordinates which helps to transform the index
 * spaced egde data into real world coordinates.
 *
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public abstract class AbstractProducer
implements            RingsHandler
{
    /**
     * min x coord of the world.
     */
    protected double minX;

    /**
     * min y coord of the world.
     */
    protected double minY;

    /**
     * max x coord of the world.
     */
    protected double maxX;

    /**
     * max y coord of the world.
     */
    protected double maxY;

    /**
     * Default constructor.
     */
    public AbstractProducer() {
    }

    /**
     * Constructor to create an Abstract producer with a
     * given world bounding box.
     * @param minX Min x coord of the world.
     * @param minY Min y coord of the world.
     * @param maxX Max x coord of the world.
     * @param maxY Max y coord of the world.
     */
    public AbstractProducer(
        double minX, double minY,
        double maxX, double maxY
    ) {
        this.minX = minX;
        this.minY = minY;
        this.maxX = maxX;
        this.maxY = maxY;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
